==> repl-server-0.0.1.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# REPL

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> REPL environment.

<section class="installation">

## Installation

```bash
npm install @stdlib/repl-server
```

</section>

<section class="usage">

## Usage

```javascript
var repl = require( '@stdlib/repl-server' );
```

#### repl( \[options], clbk )

Starts a REPL environment.

<!-- run-disable -->

```javascript
repl( onStart );

function onStart( error, server ) {
    if ( error ) {
        throw error;
    }
}
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var repl = require( '@stdlib/repl-server' );

// Start the REPL:
repl( onStart );

function onStart( error, server ) {
    if ( error ) {
        throw error;
    }
    // After the REPL has started, exit the process...
    setTimeout( onTimeout, 2500 );

    function onTimeout() {
        server.close();
    }
}
```

</section>

<!-- /.examples -->

* * *

<section class="cli">

## CLI

<section class="installation">

## Installation

To use the module as a general utility, install the module globally

```bash
npm install -g @stdlib/repl-server
```

</section>

<section class="usage">

### Usage

```text
Usage: stdlib-repl-server [options]

Options:

  -h,    --help                Print this message.
  -V,    --version             Print the package version.
```

</section>

<!-- /.usage -->

<section class="examples">

### Examples

```bash
$ stdlib-repl-server
Starting REPL...
```

</section>

<!-- /.examples -->

</section>

<!-- /.cli -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/repl-server.svg
[npm-url]: https://npmjs.org/package/@stdlib/repl-server

[test-image]: https://github.com/stdlib-js/repl-server/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/repl-server/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/repl-server/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/repl-server?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/repl-server
[dependencies-url]: https://david-dm.org/stdlib-js/repl-server/main

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/repl-server/main/LICENSE

</section>

<!-- /.links -->

==> repl-server-0.0.3.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# REPL

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> REPL environment.

<section class="installation">

## Installation

```bash
npm install @stdlib/repl-server
```

</section>

<section class="usage">

## Usage

```javascript
var repl = require( '@stdlib/repl-server' );
```

#### repl( \[options], clbk )

Starts a REPL environment.

<!-- run-disable -->

```javascript
repl( onStart );

function onStart( error, server ) {
    if ( error ) {
        throw error;
    }
}
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var repl = require( '@stdlib/repl-server' );

// Start the REPL:
repl( onStart );

function onStart( error, server ) {
    if ( error ) {
        throw error;
    }
    // After the REPL has started, exit the process...
    setTimeout( onTimeout, 2500 );

    function onTimeout() {
        server.close();
    }
}
```

</section>

<!-- /.examples -->

* * *

<section class="cli">

## CLI

<section class="installation">

## Installation

To use the module as a general utility, install the module globally

```bash
npm install -g @stdlib/repl-server
```

</section>

<section class="usage">

### Usage

```text
Usage: stdlib-repl-server [options]

Options:

  -h,    --help                Print this message.
  -V,    --version             Print the package version.
```

</section>

<!-- /.usage -->

<section class="examples">

### Examples

```bash
$ stdlib-repl-server
Starting REPL...
```

</section>

<!-- /.examples -->

</section>

<!-- /.cli -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/repl-server.svg
[npm-url]: https://npmjs.org/package/@stdlib/repl-server

[test-image]: https://github.com/stdlib-js/repl-server/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/repl-server/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/repl-server/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/repl-server?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/repl-server.svg
[dependencies-url]: https://david-dm.org/stdlib-js/repl-server/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/repl-server/main/LICENSE

</section>

<!-- /.links -->
